@@ -1,24 +1,11 @@
 # -*- coding: utf-8 -*-
 
-from zipfile import (
-    ZIP_STORED,
-    ZIP64_LIMIT,
-    ZIP_FILECOUNT_LIMIT,
-    ZIP_MAX_COMMENT,
-    ZIP_DEFLATED,
-    zlib,
-    crc32
-)
 import io
 import stat
-from io import RawIOBase
-from zipfile import ZipFile, ZipInfo
-
-#from zipfly import __version__
-__version__ = '5.0.4'
-
-class Stream(RawIOBase):
+import zipfile
+__version__ = '6.0.1'
 
+class ZipflyStream( io.RawIOBase ):
 
     """
     The RawIOBase ABC extends IOBase. It deals with
@@ -28,14 +15,14 @@ class Stream(RawIOBase):
 
     def __init__(self):
         self._buffer = b''
-        self._size=0
+        self._size = 0
 
     def writable(self):
         return True
 
     def write(self, b):
         if self.closed:
-            raise ValueError('Stream was closed!')
+            raise RuntimeError("ZipFly stream was closed!")
         self._buffer += b
         return len(b)
 
@@ -55,20 +42,23 @@ class ZipFly:
                  mode = 'w',
                  paths = [],
                  chunksize = 0x4000,
-                 compression = ZIP_STORED,
+                 compression = zipfile.ZIP_STORED,
                  allowZip64 = True,
                  compresslevel = None,
-                 storesize = 0):
+                 storesize = 0,
+                 filesystem = 'fs',
+                 arcname = 'n',
+                 encode = 'utf-8',):
 
         """
-            @param store size : int : size of all files
-            in paths without compression
+        @param store size : int : size of all files
+        in paths without compression
         """
 
         if mode not in ('w',):
             raise RuntimeError("ZipFly requires 'w' mode")
 
-        if compression not in ( ZIP_STORED,):
+        if compression not in ( zipfile.ZIP_STORED,):
             raise RuntimeError("Not compression supported")
 
         if compresslevel not in (None, ):
@@ -78,14 +68,14 @@ class ZipFly:
         self.comment = f'Written using Zipfly v{__version__}'
         self.mode = mode
         self.paths = paths
-        self.filesystem = 'fs'
-        self.arcname = 'n'
+        self.filesystem = filesystem
+        self.arcname = arcname
         self.chunksize = int(chunksize)
         self.compression = compression
         self.allowZip64 = allowZip64
         self.compresslevel = compresslevel
         self.storesize = storesize
-        self.encode = 'utf-8'
+        self.encode = encode
         self.ezs = 0x8e # empty zip size in bytes
 
     def set_comment(self, comment):
@@ -93,10 +83,10 @@ class ZipFly:
         if not isinstance(comment, bytes):
             comment = str.encode(comment)
 
-        if len(comment) >= ZIP_MAX_COMMENT:
+        if len(comment) >= zipfile.ZIP_MAX_COMMENT:
 
             # trunk comment
-            comment = comment[:ZIP_MAX_COMMENT]
+            comment = comment[:zipfile.ZIP_MAX_COMMENT]
 
         self.comment = comment
 
@@ -112,9 +102,9 @@ class ZipFly:
     def buffer_size(self):
 
         '''
-            FOR UNIT TESTING (not used)
-            using to get the buffer size
-            this size is different from the size of each file added
+        FOR UNIT TESTING (not used)
+        using to get the buffer size
+        this size is different from the size of each file added
         '''
 
         for i in self.generator(): pass
@@ -169,7 +159,6 @@ class ZipFly:
                 name = self.filesystem
 
             tmp_name = path[name]
-
             if (tmp_name)[0] in ('/', ):
                 # is dir then trunk
                 tmp_name = (tmp_name)[ 1 : len( tmp_name ) ]
@@ -192,17 +181,21 @@ class ZipFly:
     def generator(self):
 
         # stream
-        stream = Stream()
+        stream = ZipflyStream()
 
-        with ZipFile(stream,
-                     mode = self.mode,
-                     compression = self.compression,
-                     allowZip64 = self.allowZip64,) as zf:
+        with zipfile.ZipFile(
+            stream,
+            mode = self.mode,
+            compression = self.compression,
+            allowZip64 = self.allowZip64,) as zf:
 
             for path in self.paths:
 
                 if not self.filesystem in path:
-                    raise RuntimeError(" 'fs' key is required ")
+
+                    raise RuntimeError(
+                        f" '{self.filesystem}' key is required "
+                    )
 
                 """
                 filesystem should be the path to a file or directory on the filesystem.
@@ -210,36 +203,38 @@ class ZipFly:
                 this will be the same as filename
                 """
 
-                if self.arcname in path:
-                    z_info = ZipInfo.from_file(
-                        path[self.filesystem],
-                        path[self.arcname]
-                    )
-                else:
-                    z_info = ZipInfo.from_file(
-                        path[self.filesystem]
-                    )
+                if not self.arcname in path:
+
+                    # arcname will be default path
+                    path[self.arcname] = path[self.filesystem]
+
+                z_info = zipfile.ZipInfo.from_file(
+                    path[self.filesystem],
+                    path[self.arcname]
+                )
 
                 with open( path[self.filesystem], 'rb' ) as e:
+                    # Read from filesystem:
 
                     with zf.open( z_info, mode = self.mode ) as d:
 
                         for chunk in iter( lambda: e.read( self.chunksize ), b'' ):
 
-                            # write chunk to zip file
-                            d.write( chunk )
+                            # (e.read( ... )) this get a small chunk of the file
+                            # and return a callback to the next iterator
 
-                            # getting bytes from stream to the next iterator
+                            d.write( chunk )
                             yield stream.get()
 
 
             self.set_comment(self.comment)
             zf.comment = self.comment
 
-        # last piece
+        # last chunk
         yield stream.get()
 
-        # TESTING (not used)
+        # (TESTING)
+        # get the real size of the zipfile
         self._buffer_size = stream.size()
 
         # Flush and close this stream.
